# Demineur
Ce projet est une réplique du jeu vidéo "Démineur" de Google (https://g.co/kgs/AFPEqsi).
C'est un jeu de réflexion dont le but est de localiser des mines cachées dans une grille représentant un champ de mines virtuel, avec pour seule indication le nombre de mines dans les zones adjacentes.
